@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 module Mail
 
   # A delivery method implementation which sends via exim.
@@ -43,7 +44,7 @@ module Mail
 
     def self.call(path, arguments, destinations, mail)
       popen "#{path} #{arguments}" do |io|
-        io.puts mail.encoded.to_lf
+        io.puts ::Mail::Utilities.to_lf(mail.encoded)
         io.flush
       end
     end
