@@ -1,6 +1,11 @@
 # encoding: utf-8
+# frozen_string_literal: true
 module Mail
   module Utilities
+
+    LF   = "\n"
+    CRLF = "\r\n"
+
     include Constants
 
     # Returns true if the string supplied is free from characters not allowed as an ATOM
@@ -19,13 +24,11 @@ module Mail
     def quote_phrase( str )
       if RUBY_VERSION >= '1.9'
         original_encoding = str.encoding
-        str.force_encoding('ASCII-8BIT')
-        if (PHRASE_UNSAFE === str)
-          quoted_str = dquote(str).force_encoding(original_encoding)
-          str.force_encoding(original_encoding)
-          quoted_str
+        ascii_str = str.dup.force_encoding('ASCII-8BIT')
+        if (PHRASE_UNSAFE === ascii_str)
+          dquote(ascii_str).force_encoding(original_encoding)
         else
-          str.force_encoding(original_encoding)
+          str
         end
       else
         (PHRASE_UNSAFE === str) ? dquote(str) : str
@@ -221,5 +224,56 @@ module Mail
 
     end
 
+    # Test String#encode works correctly with line endings.
+    # Some versions of Ruby (e.g. MRI <1.9, JRuby, Rubinius) line ending
+    # normalization does not work correctly or did not have #encode.
+    if ("\r".encode(:universal_newline => true) rescue nil) == LF &&
+      (LF.encode(:crlf_newline => true) rescue nil) == CRLF
+      # Using String#encode is better performing than Regexp
+
+      def self.to_lf(input)
+        input.kind_of?(String) ? input.to_str.encode(input.encoding, :universal_newline => true) : ''
+      end
+
+      def self.to_crlf(input)
+        input.kind_of?(String) ? input.to_str.encode(input.encoding, :universal_newline => true).encode!(input.encoding, :crlf_newline => true) : ''
+      end
+
+    else
+
+      def self.to_lf(input)
+        input.kind_of?(String) ? input.to_str.gsub(/\r\n|\r/, LF) : ''
+      end
+
+      if RUBY_VERSION >= '1.9'
+        # This 1.9 only regex can save a reasonable amount of time (~20%)
+        # by not matching "\r\n" so the string is returned unchanged in
+        # the common case.
+        CRLF_REGEX = Regexp.new("(?<!\r)\n|\r(?!\n)")
+      else
+        CRLF_REGEX = /\n|\r\n|\r/
+      end
+
+      def self.to_crlf(input)
+        input.kind_of?(String) ? input.to_str.gsub(CRLF_REGEX, CRLF) : ''
+      end
+
+    end
+
+    # Returns true if the object is considered blank.
+    # A blank includes things like '', '   ', nil,
+    # and arrays and hashes that have nothing in them.
+    #
+    # This logic is mostly shared with ActiveSupport's blank?
+    def self.blank?(value)
+      if value.kind_of?(NilClass)
+        true
+      elsif value.kind_of?(String)
+        value !~ /\S/
+      else
+        value.respond_to?(:empty?) ? value.empty? : !value
+      end
+    end
+
   end
 end
