@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 require 'spec_helper'
 
 describe Mail::Body do
@@ -448,4 +449,12 @@ describe Mail::Body do
       expect(body.encoded).to eq expect
     end
   end
+
+  describe "invalid encoding" do
+    it "should round trip" do
+      body = Mail::Body.new('The Body')
+      body.encoding = 'invalid'
+      expect(body.encoded).to eq 'The Body'
+    end
+  end
 end
