@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 require 'spec_helper'
 
 describe Mail::PhraseList do
@@ -11,7 +12,7 @@ describe Mail::PhraseList do
 
     it "should raise an error if the input is useless" do
       parse_text = nil
-      expect { Mail::PhraseList.new(parse_text) }.to raise_error
+      expect { Mail::PhraseList.new(parse_text) }.to raise_error(Mail::Field::ParseError)
     end
 
     it "should not raise an error if the input is empty" do
