@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 require 'spec_helper'
 
 describe Mail::Field do
@@ -99,6 +100,13 @@ describe Mail::Field do
       field.addresses
     end
 
+    it "should respond_to? its own methods and the same methods as its instantiated field class" do
+      field = Mail::Field.new('To: Bob')
+      expect(field.respond_to?(:field)).to be_truthy
+      expect(field.field).to receive(:"respond_to?").once
+      field.respond_to?(:addresses)
+    end
+
     it "should change its type if you change the name" do
       field = Mail::Field.new("To: mikel@me.com")
       expect(field.field.class).to eq Mail::ToField
@@ -116,6 +124,12 @@ describe Mail::Field do
       field = Mail::Field.new('Subject: こんにちは', charset)
       expect(field.charset).to eq charset
     end
+
+    it "should not strip out content that looks like the field name" do
+      pending "pr#766"
+      field = Mail::Field.new('Subject: subject: for your approval')
+      expect(field.value).to eq 'subject: for your approval'
+    end
   end
 
   describe "error handling" do
@@ -144,14 +158,34 @@ describe Mail::Field do
       expect(field.responsible_for?(:to)).to be_truthy
     end
 
-    it "should say it is == to another if their field names match" do
+    it "should say it is the \"same\" as another if their field types match" do
       expect(Mail::Field.new("To: mikel").same(Mail::Field.new("To: bob"))).to be_truthy
     end
 
+    it "should say it is not the \"same\" as another if their field types don't match" do
+      expect(Mail::Field.new("To: mikel").same(Mail::Field.new("From: mikel"))).to be_falsey
+    end
+
+    it "should say it is not the \"same\" as nil" do
+      expect(Mail::Field.new("To: mikel").same(nil)).to be_falsey
+    end
+
+    it "should say it is == to another if their field and names match" do
+      expect(Mail::Field.new("To: mikel")).to eq(Mail::Field.new("To: mikel"))
+    end
+
     it "should say it is not == to another if their field names do not match" do
       expect(Mail::Field.new("From: mikel")).not_to eq(Mail::Field.new("To: bob"))
     end
 
+    it "should say it is not == to another if their field names match, but not their values" do
+      expect(Mail::Field.new("To: mikel")).not_to eq(Mail::Field.new("To: bob"))
+    end
+
+    it "should say it is not == to nil" do
+      expect(Mail::Field.new("From: mikel")).not_to eq(nil)
+    end
+
     it "should sort according to the field order" do
       list = [Mail::Field.new("To: mikel"), Mail::Field.new("Return-Path: bob")]
       expect(list.sort[0].name).to eq "Return-Path"
@@ -159,7 +193,7 @@ describe Mail::Field do
   end
 
   describe 'user defined fields' do
-    it "should say it is == to another if their field names match" do
+    it "should say it is the \"same\" as another if their field names match" do
       expect(Mail::Field.new("X-Foo: mikel").same(Mail::Field.new("X-Foo: bob"))).to be_truthy
     end
 
