@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 require 'spec_helper'
 
 describe "MIME Emails" do
@@ -144,6 +145,13 @@ describe "MIME Emails" do
         expect(mail.text_part).to eq text_mail
       end
 
+      it "should convert strings assigned to the text part into Mail::Part objects with sensible defaults" do
+        mail = Mail.new
+        mail.text_part = 'This is text'
+        expect(mail.text_part.body).to eq 'This is text'
+        expect(mail.text_part.content_type).to eq 'text/plain'
+      end
+
       it "should not assign a nil text part" do
         mail = Mail.new
         mail.text_part = nil
@@ -157,6 +165,13 @@ describe "MIME Emails" do
         expect(mail.html_part).to eq html_mail
       end
 
+      it "should convert strings assigned to the html part into Mail::Part objects with sensible defaults" do
+        mail = Mail.new
+        mail.html_part = "<b>This is HTML</b>"
+        expect(mail.html_part.body).to eq "<b>This is HTML</b>"
+        expect(mail.html_part.content_type).to eq "text/html"
+      end
+
       it "should not assign a nil html part" do
         mail = Mail.new
         mail.html_part = nil
@@ -503,6 +518,12 @@ describe "MIME Emails" do
         end
       end
 
+      it "should support :mime_type option" do
+        mail = Mail::Message.new
+        mail.add_file(:filename => 'test.png', :content => 'a', :mime_type=>'text/plain')
+        expect(mail.attachments.first.content_type).to eq 'text/plain'
+      end
+
       it "should be able to add a body before adding a file" do
         m = Mail.new do
           from    'mikel@from.lindsaar.net'
