@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 require 'spec_helper'
 
 describe "IMAP Retriever" do
@@ -164,7 +165,7 @@ describe "IMAP Retriever" do
 
   describe "connection" do
     it "should raise an Error if no block is given" do
-      expect { Mail.connection { |m| raise ArgumentError.new } }.to raise_error
+      expect { Mail.connection { |m| raise ArgumentError.new } }.to raise_error(ArgumentError)
     end
     it "should yield the connection object to the given block" do
       Mail.connection do |connection|
@@ -178,16 +179,16 @@ describe "IMAP Retriever" do
       retrievable = Mail::IMAP.new({})
       options = retrievable.send(:validate_options, {})
 
-      expect(options[:count]).not_to be_blank
+      expect(Mail::Utilities.blank?(options[:count])).not_to be_truthy
       expect(options[:count]).to eq 10
 
-      expect(options[:order]).not_to be_blank
+      expect(Mail::Utilities.blank?(options[:order])).not_to be_truthy
       expect(options[:order]).to eq :asc
 
-      expect(options[:what]).not_to be_blank
+      expect(Mail::Utilities.blank?(options[:what])).not_to be_truthy
       expect(options[:what]).to eq :first
 
-      expect(options[:mailbox]).not_to be_blank
+      expect(Mail::Utilities.blank?(options[:mailbox])).not_to be_truthy
       expect(options[:mailbox]).to eq 'INBOX'
     end
     it "should not replace given configuration" do
@@ -199,16 +200,16 @@ describe "IMAP Retriever" do
         :what => :first
       })
 
-      expect(options[:count]).not_to be_blank
+      expect(Mail::Utilities.blank?(options[:count])).not_to be_truthy
       expect(options[:count]).to eq 2
 
-      expect(options[:order]).not_to be_blank
+      expect(Mail::Utilities.blank?(options[:order])).not_to be_truthy
       expect(options[:order]).to eq :asc
 
-      expect(options[:what]).not_to be_blank
+      expect(Mail::Utilities.blank?(options[:what])).not_to be_truthy
       expect(options[:what]).to eq :first
 
-      expect(options[:mailbox]).not_to be_blank
+      expect(Mail::Utilities.blank?(options[:mailbox])).not_to be_truthy
       expect(options[:mailbox]).to eq 'some/mail/box'
     end
     it "should ensure utf7 conversion for mailbox names" do
@@ -226,7 +227,7 @@ describe "IMAP Retriever" do
     it "should finish the IMAP connection if an exception is raised" do
       expect(MockIMAP).to be_disconnected
 
-      expect { Mail.all { |m| raise ArgumentError.new } }.to raise_error
+      expect { Mail.all { |m| raise ArgumentError.new } }.to raise_error(ArgumentError)
 
       expect(MockIMAP).to be_disconnected
     end
