@@ -1,4 +1,5 @@
 # encoding: utf-8
+# frozen_string_literal: true
 require File.expand_path('../environment', __FILE__)
 
 unless defined?(MAIL_ROOT)
@@ -46,8 +47,7 @@ end
 # We can assume if a, m and z and 1, 5, 0 work, then the rest
 # of the letters and numbers work.
 def ascii(from = 33, to = 126)
-  chars = []
-  from.upto(to) { |c| chars << ('' << c) }
+  chars = (from..to).map(&:chr)
   boring = ('b'..'l').to_a + ('n'..'o').to_a +
     ('p'..'y').to_a + ('B'..'L').to_a + ('N'..'O').to_a +
     ('P'..'Y').to_a + ('1'..'4').to_a + ('6'..'8').to_a
